package com.chelvc.framework.base.util;

import java.nio.charset.StandardCharsets;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.safety.Whitelist;

/**
 * Jsoup工具类
 *
 * @author Woody
 * @date 2023/4/5
 */
public final class JsoupUtils {
    /**
     * 白名单
     */
    private static final Whitelist WHITELIST = Whitelist.relaxed();

    /**
     * 文档输出设置
     */
    private static final Document.OutputSettings OUTPUT_SETTINGS =
            new Document.OutputSettings().charset(StandardCharsets.UTF_8).prettyPrint(false);

    static {
        // 初始化白名单
        WHITELIST.addTags("figure");
        WHITELIST.addAttributes(":all", "class");
        WHITELIST.addAttributes(":all", "style");
    }

    private JsoupUtils() {
    }

    /**
     * 清理数据
     *
     * @param value 数据值
     * @return 清理后的数据值
     */
    public static String clean(String value) {
        return StringUtils.isEmpty(value) ? value : Jsoup.clean(value, StringUtils.EMPTY, WHITELIST, OUTPUT_SETTINGS);
    }

    /**
     * 清理数据
     *
     * @param values 数据值数组
     * @return 清理后的数据值数组
     */
    public static String[] clean(String[] values) {
        if (values == null || values.length == 0) {
            return values;
        }
        String[] cleans = new String[values.length];
        for (int i = 0, size = values.length; i < size; i++) {
            cleans[i] = clean(values[i]);
        }
        return cleans;
    }
}